export default function middleware() {
  return (next) => (action) => {
    // Получаем promise из action(параметров)
    const { promise, ...rest } = action;

    // Если его нет, то пропускаем обработку
    if (!promise) {
      return next(action);
    }

    // Если найден, то переводим загрузку в состояние loading
    // и по завершении загрузки переводим загрузку в success или failure
    // все действия возвращаем в наш action (из которого получен promise)
    next({ ...rest, readyState: 'loading' });
    return promise.then(
      success =>
        success.json().then(
          result => next({ ...rest, result, readyState: 'success' }),
          error => next({ ...rest, error, readyState: 'failure' })
        ),
      error => next({ ...rest, error, readyState: 'failure' })
    );
  };
}